@@ -38,6 +38,13 @@ def _get_uranium(uranium_file):
 
 def _activate_virtualenv(uranium_dir):
     """ this will activate a virtualenv in the case one exists """
+    # if the pyvenv launcher environment variable is set, it causes the install directory
+    # to be that directory.
+    # we want the virtualenv directory to be the one we just created, so we remove
+    # this variable
+    if '__PYVENV_LAUNCHER__' in os.environ:
+        del os.environ['__PYVENV_LAUNCHER__']
+
     activate_this_path = os.path.join(uranium_dir, 'bin', 'activate_this.py')
     with open(activate_this_path) as fh:
         exec(fh.read(), {'__file__': activate_this_path}, {})
